<?php

namespace Payroll\Salary\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Payroll\Salary\Interfaces\SalaryRepositoryInterface;
use Payroll\Salary\Repositories\Presenter\SalaryItemTransformer;

/**
 * Pubic API controller class.
 */
class SalaryPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Payroll\Salary\Interfaces\SalaryRepositoryInterface $salary
     *
     * @return type
     */
    public function __construct(SalaryRepositoryInterface $salary)
    {
        $this->repository = $salary;
        parent::__construct();
    }

    /**
     * Show salary's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $salaries = $this->repository
            ->setPresenter('\\Payroll\\Salary\\Repositories\\Presenter\\SalaryListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $salaries['code'] = 2000;
        return response()->json($salaries)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show salary.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $salary = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($salary)) {
            $salary         = $this->itemPresenter($module, new SalaryItemTransformer);
            $salary['code'] = 2001;
            return response()->json($salary)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
