<?php

namespace Payroll\Salary\Http\Controllers;
use Litepie\Salary\Http\Requests\SalaryRequest;
use Litepie\Salary\Models\Salary;

trait SalaryWorkflow {
	
    /**
     * Workflow controller function for salary.
     *
     * @param Model   $salary
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SalaryRequest $request, Salary $salary, $step)
    {

        try {

            $salary->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('salary::salary.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/salary/salary/' . $salary->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/salary/salary/' . $salary->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for salary.
     *
     * @param Model   $salary
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Salary $salary, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $salary->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('salary::salary.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('salary::admin.salary.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('salary::admin.salary.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('salary::admin.salary.message', $data)->render();

        }

    }
}