<?php

namespace Payroll\Salary\Policies;

use App\User;
use Payroll\Salary\Models\Salary;

class SalaryPolicy
{

    /**
     * Determine if the given user can view the salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function view(User $user, Salary $salary)
    {
        if ($user->canDo('salary.salary.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $salary->user_id;
    }

    /**
     * Determine if the given user can create a salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('salary.salary.create');
    }

    /**
     * Determine if the given user can update the given salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function update(User $user, Salary $salary)
    {
        if ($user->canDo('salary.salary.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $salary->user_id;
    }

    /**
     * Determine if the given user can delete the given salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function destroy(User $user, Salary $salary)
    {
        if ($user->canDo('salary.salary.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $salary->user_id;
    }

    /**
     * Determine if the given user can verify the given salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function verify(User $user, Salary $salary)
    {
        if ($user->canDo('salary.salary.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('salary.salary.verify') 
        && $user->is('manager')
        && $salary->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given salary.
     *
     * @param User $user
     * @param Salary $salary
     *
     * @return bool
     */
    public function approve(User $user, Salary $salary)
    {
        if ($user->canDo('salary.salary.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
