<?php

namespace Payroll\Salary\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Payroll\Salary\Models\Salary;

class SalaryAction
{
    /**
     * Perform the complete action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */
    public function complete(Salary $salary)
    {
        try {
            $salary->status = 'complete';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */public function verify(Salary $salary)
    {
        try {
            $salary->status = 'verify';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */public function approve(Salary $salary)
    {
        try {
            $salary->status = 'approve';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */public function publish(Salary $salary)
    {
        try {
            $salary->status = 'publish';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */
    public function archive(Salary $salary)
    {
        try {
            $salary->status = 'archive';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Salary $salary
     *
     * @return Salary
     */
    public function unpublish(Salary $salary)
    {
        try {
            $salary->status = 'unpublish';
            return $salary->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
