<?php

namespace Payroll\Salary\Workflow;

use Payroll\Salary\Models\Salary;
use Validator;

class SalaryValidator
{

    /**
     * Determine if the given salary is valid for complete status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function complete(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given salary is valid for verify status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function verify(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given salary is valid for approve status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function approve(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given salary is valid for publish status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function publish(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given salary is valid for archive status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function archive(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given salary is valid for unpublish status.
     *
     * @param Salary $salary
     *
     * @return bool / Validator
     */
    public function unpublish(Salary $salary)
    {
        return Validator::make($salary->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
